<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ady">
<context>
    <name>Action</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="188"/>
        <source>Display in file manager</source>
        <translation>Файлы менеджерҙа күрһәте</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="489"/>
        <source>Clear log</source>
        <translation>Журналды тазалаштырыр</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="189"/>
        <source>Refresh</source>
        <translation>Яңылау</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="539"/>
        <source>Are you sure you want to clear the log?</source>
        <translation>Журналды тазалаштырырга ишенәсез?</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="540"/>
        <source>Cancel</source>
        <translation>Башҡа</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="541"/>
        <source>Confirm</source>
        <translation>Тикшереү</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <location filename="../application/filtercontent.cpp" line="80"/>
        <source>All</source>
        <translation>Барлыҡ</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="83"/>
        <source>Today</source>
        <translation>Бүгөн</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="86"/>
        <source>3 days</source>
        <translation>3 көн</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="89"/>
        <source>1 week</source>
        <translation>1 һәбәт</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="92"/>
        <source>1 month</source>
        <translation>1 ай</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="95"/>
        <source>3 months</source>
        <translation>3 ай</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="224"/>
        <source>Export</source>
        <comment>button</comment>
        <translation>Экспорт</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <location filename="../application/filtercontent.cpp" line="120"/>
        <source>All</source>
        <translation>Барлыҡ</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="121"/>
        <source>Emergency</source>
        <translation>Авария</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="122"/>
        <source>Alert</source>
        <translation>Хәбәр</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="123"/>
        <source>Critical</source>
        <translation>Ҡырыҡ</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="124"/>
        <source>Error</source>
        <translation>Хата</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="125"/>
        <source>Warning</source>
        <translation>Уйлап ҡуйыу</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="126"/>
        <source>Notice</source>
        <translation>Ихтимал</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="127"/>
        <source>Info</source>
        <translation>Инфо</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="128"/>
        <source>Debug</source>
        <translation>Дебаг</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="198"/>
        <source>Login</source>
        <translation>Күсеп кил</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="199"/>
        <source>Boot</source>
        <translation>Старт</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="200"/>
        <source>Shutdown</source>
        <translation>Төшөр</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="142"/>
        <source>Super critical</source>
        <translation>Төп ҡырыҡ</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="148"/>
        <source>Trace</source>
        <translation>Трасс</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="212"/>
        <source>Identity authentication</source>
        <translation>Идентификация аутентификация</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="213"/>
        <source>Discretionary Access Control</source>
        <translation>Сәйәсәттән ҡушылған ҡабул итеү</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="214"/>
        <source>Mandatory access control</source>
        <translation>Мөмкин булмаған ҡабул итеү</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="215"/>
        <source>Remote</source>
        <translation>Ремо</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="216"/>
        <source>Document audit</source>
        <translation>Документ аудит</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="217"/>
        <source>Other</source>
        <translation>Другой</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="1800"/>
        <source>zip(*.zip)</source>
        <translation>zip(*.zip)</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="1794"/>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <location filename="../application/exportprogressdlg.cpp" line="35"/>
        <source>Exporting...</source>
        <translation>Экспорт...</translation>
    </message>
    <message>
        <location filename="../application/exportprogressdlg.cpp" line="58"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="3257"/>
        <source>Export successful</source>
        <translation>Экспорт успешен</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3260"/>
        <source>Export failed</source>
        <translation>Экспорт провален</translation>
    </message>
    <message>
        <location filename="../application/logbackend.cpp" line="1763"/>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation>Директория экспорт не доступна. Пожалуйста, выберите другую директорию для операции экспорта.</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="1792"/>
        <source>Export File</source>
        <translation>Экспортировать файл</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <location filename="../application/filtercontent.cpp" line="76"/>
        <source>Period:</source>
        <translation>Период:</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="114"/>
        <source>Level:  </source>
        <translation>Уровень:</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="180"/>
        <source>Status:</source>
        <translation>Статус:</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="193"/>
        <source>Event Type:</source>
        <translation>Тип события:</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="132"/>
        <source>User:</source>
        <translation>Пользователь:</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="134"/>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="138"/>
        <source>Action:</source>
        <translation>Действие:</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="143"/>
        <source>Username:</source>
        <translation>Имя пользователя:</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="469"/>
        <source>Boot record</source>
        <translation>Запись загрузки</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="471"/>
        <source>Shutdown record</source>
        <translation>Запись выключения</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="474"/>
        <source>Login record</source>
        <translation>Запись входа</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="208"/>
        <source>Audit Type:</source>
        <translation>Тип аудита:</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="155"/>
        <source>Application:</source>
        <translation>Приложение:</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="167"/>
        <source>Submodule:</source>
        <translation>Подмодуль:</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="201"/>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="202"/>
        <source>Debug</source>
        <translation>Отладка</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="203"/>
        <source>Info</source>
        <translation>Информация</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="204"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="208"/>
        <source>Emergency</source>
        <translation>Чрезвычайная</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="209"/>
        <source>Alert</source>
        <translation>ئەلەرت</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="210"/>
        <source>Critical</source>
        <translation>كىرېتىك</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="213"/>
        <source>Notice</source>
        <translation>نىوتىس</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="220"/>
        <source>Trace</source>
        <translation>تەيس</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="226"/>
        <source>Super critical</source>
        <translation>سۈپېر كىرېتىك</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <location filename="../application/logauththread.cpp" line="529"/>
        <source>Log file is empty</source>
        <translation>لۆج فايلى خالى</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../application/main.cpp" line="329"/>
        <source>Log Viewer</source>
        <translation>لۆج كۆرۈشچىسى</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="332"/>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>سېستېم لۆجلىرىنى كۆرۈش چۈشىنى ئۇسۇللىق ئۇيغۇن ھەققىدە ئىشلەتكەن چۈشىنى ئۇسۇللىق</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="120"/>
        <source>No search results</source>
        <translation>ئىزەچىلىش نەتىجىسى بار</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="109"/>
        <source>Search</source>
        <translation>ئىزەچىلىش</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="563"/>
        <source>Level</source>
        <translation>سەۋەپ</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="564"/>
        <source>Process</source>
        <translation>پىرۆس</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="565"/>
        <source>Date and Time</source>
        <translation>تەرەخ ۋە زامان</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="566"/>
        <source>Info</source>
        <translation>مەلۇمات</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="567"/>
        <source>User</source>
        <translation>كىسى</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="568"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="953"/>
        <source>Source</source>
        <translation>مەنچى</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="669"/>
        <source>Action</source>
        <translation>ھەرىكەت</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3374"/>
        <source>Status</source>
        <translation>ھال</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="1140"/>
        <source>Event Type</source>
        <translation>ھەرىكەت نەچىسى</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="1141"/>
        <source>Username</source>
        <translation>كىسى نىسىى</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="897"/>
        <source>Level:</source>
        <translation>سەۋەپ:</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="898"/>
        <source>Process:</source>
        <translation>پىرۆس:</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="899"/>
        <source>Date and Time:</source>
        <translation>تەرەخ ۋە زامان:</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="901"/>
        <source>Info:</source>
        <translation>مەلۇمات:</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="902"/>
        <source>Null</source>
        <translation>ھەققىدە</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="906"/>
        <source>User:</source>
        <translation>كىسى:</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="907"/>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3532"/>
        <source>File Name</source>
        <translation>فەيل نىسىى</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3533"/>
        <source>Time Modified</source>
        <translation>تەرەخىنى تەھرىر قىلغان زامان</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3741"/>
        <source>SIG</source>
        <translation>السِّجِّيل</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3745"/>
        <source>EXE</source>
        <translation>البرنامج</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3743"/>
        <source>Core File</source>
        <translation>ملف التصحيح</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3744"/>
        <source>User Name </source>
        <translation>اسم المستخدم</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="1009"/>
        <source>Offset</source>
        <translation>الانحراف</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="1142"/>
        <source>Date and Time</source>
        <translation>التاريخ والوقت</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <location filename="../application/loglistview.cpp" line="171"/>
        <source>System Log</source>
        <translation>سجل النظام</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="182"/>
        <source>Kernel Log</source>
        <translation>سجل النواة</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="203"/>
        <source>Boot Log</source>
        <translation>سجل التشغيل</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="232"/>
        <source>dpkg Log</source>
        <translation>سجل dpkg</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="244"/>
        <source>Kwin Log</source>
        <translation>سجل Kwin</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="253"/>
        <source>Xorg Log</source>
        <translation>سجل Xorg</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="265"/>
        <source>Application Log</source>
        <translation>سجل التطبيق</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="290"/>
        <source>Boot-Shutdown Event</source>
        <translation>حدث التشغيل والإيقاف</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="222"/>
        <source>dnf Log</source>
        <translation>سجل dnf</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="303"/>
        <source>Other Log</source>
        <translation>سجل آخر</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="339"/>
        <source>Custom Log</source>
        <translation>سجل مخصص</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="319"/>
        <source>Audit Log</source>
        <translation>سجل المراجعة</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="278"/>
        <source>Coredump Log</source>
        <translation>سجل التصحيح</translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="133"/>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation>لا يمكن جمع معلومات الحوادث، من فضلك تثبيت systemd-coredump.</translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="139"/>
        <source>You do not have permission to view it</source>
        <translation>ليس لديك صلاحية لعرض هذا</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3216"/>
        <source>Audit log is not exist.</source>
        <translation>سجل المراجعة غير موجود.</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="127"/>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation>مستوى الأمان للنظام الحالي: مرتفع
 يمكن رؤية سجل المراجعة فقط من قبل المسؤولين</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../application/main.cpp" line="67"/>
        <source>Export logs to the specified path</source>
        <translation>تصدير السجلات إلى المسار المحدد</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="67"/>
        <source>PATH</source>
        <translation>المسار</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="68"/>
        <source>Export logs of specified types</source>
        <translation>تصدير السجلات من نوع معين</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="68"/>
        <source>TYPE</source>
        <translation>النوع</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="69"/>
        <source>Export logs of specified self-developed applications</source>
        <translation>تصدير السجلات من التطبيقات المطورة ذاتيًا</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="69"/>
        <source>SELF APPNAME</source>
        <translation>اسم التطبيق الذاتي</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="70"/>
        <source>Export logs within a specified time period</source>
        <translation>تصدير السجلات في فترة زمنية محددة</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="70"/>
        <source>PERIOD</source>
        <translation> período</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="71"/>
        <source>Export logs within a specified debug level</source>
        <translation>Exportar logs con un nivel de depuración especificado</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="71"/>
        <source>LEVEL</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="72"/>
        <source>BOOT STATUS</source>
        <translation>Estado de arranque</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="72"/>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation>Exportar logs de arranque (no-klu) con un estado especificado</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="73"/>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation>Exportar logs de eventos de apagado o auditoría con un tipo de evento especificado</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="73"/>
        <source>EVENT TYPE</source>
        <translation>Tipo de evento</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="74"/>
        <source>Export logs based on keywords search results</source>
        <translation>Exportar logs basados en resultados de búsqueda por palabras clave</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="74"/>
        <source>KEY WORD</source>
        <translation>Palabra clave</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="76"/>
        <source>Report coredump informations.</source>
        <translation>Informar sobre información de core dump.</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="75"/>
        <source>Export logs based on app submodel</source>
        <translation>Exportar logs basados en submodelo de aplicación</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="75"/>
        <source>SUBMODULE</source>
        <translation>Submódulo</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <location filename="../application/logcollectormain.cpp" line="202"/>
        <source>Refresh interval</source>
        <translation>Intervalo de actualización</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="204"/>
        <source>10 sec</source>
        <translation>10 seg</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="205"/>
        <source>1 min</source>
        <translation>1 min</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="206"/>
        <source>5 min</source>
        <translation>5 min</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="207"/>
        <source>No refresh</source>
        <translation>Sin actualización</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="234"/>
        <source>Export All</source>
        <translation>Exportar todo</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="240"/>
        <source>Refresh Now</source>
        <translation>Actualizar ahora</translation>
    </message>
</context>
</TS>
